@@ -17,9 +17,9 @@ class NERCorpus(Corpus):
         """
         super().__init__()
         if fileName is not None:
-            inputFile = open(fileName, "r", encoding="utf8")
-            lines = inputFile.readlines()
-            inputFile.close()
+            input_file = open(fileName, "r", encoding="utf8")
+            lines = input_file.readlines()
+            input_file.close()
             for line in lines:
                 self.addSentence(NamedEntitySentence(line))
 
